@@ -4,7 +4,7 @@
     original version by Matt Domsch <Matt_Domsch@dell.com>
     Disclaimed into the Public Domain
 
-    Portions Copyright (C) 2001, 2002, 2003, 2005, 2006
+    Portions Copyright (C) 2001, 2002, 2003, 2005, 2006, 2007
         Free Software Foundation, Inc.
 
     EFI GUID Partition Table handling
@@ -26,7 +26,7 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#include "config.h"
+#include <config.h>
 
 #include <parted/parted.h>
 #include <parted/debug.h>
@@ -34,8 +34,6 @@
 #include <parted/crc32.h>
 #include <inttypes.h>
 #include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
@@ -62,7 +60,12 @@
 #define GPT_HEADER_REVISION_V0_99 0x00009900
 
 typedef uint16_t efi_char16_t;	/* UNICODE character */
-
+typedef struct _GuidPartitionTableHeader_t GuidPartitionTableHeader_t;
+typedef struct _GuidPartitionEntryAttributes_t GuidPartitionEntryAttributes_t;
+typedef struct _GuidPartitionEntry_t GuidPartitionEntry_t;
+typedef struct _PartitionRecord_t PartitionRecord_t;
+typedef struct _LegacyMBR_t LegacyMBR_t;
+typedef struct _GPTDiskData GPTDiskData;
 typedef struct {
         uint32_t time_low;
         uint16_t time_mid;
@@ -121,7 +124,7 @@ typedef struct {
 		    PED_CPU_TO_LE16 (0x11AA), 0xaa, 0x11, \
 		    { 0x00, 0x30, 0x65, 0x43, 0xEC, 0xAC }})
 
-typedef struct _GuidPartitionTableHeader_t {
+struct __attribute__ ((packed)) _GuidPartitionTableHeader_t {
 	uint64_t Signature;
 	uint32_t Revision;
 	uint32_t HeaderSize;
@@ -137,9 +140,9 @@ typedef struct _GuidPartitionTableHeader_t {
 	uint32_t SizeOfPartitionEntry;
 	uint32_t PartitionEntryArrayCRC32;
 	uint8_t* Reserved2;
-} __attribute__ ((packed)) GuidPartitionTableHeader_t;
+};
 
-typedef struct _GuidPartitionEntryAttributes_t {
+struct __attribute__ ((packed)) _GuidPartitionEntryAttributes_t {
 #ifdef __GNUC__ /* XXX narrow this down to !TinyCC */
 	uint64_t RequiredToFunction:1;
 	uint64_t Reserved:47;
@@ -151,16 +154,16 @@ typedef struct _GuidPartitionEntryAttributes_t {
 	uint32_t LOST:5;
         uint32_t GuidSpecific:16;
 #endif
-} __attribute__ ((packed)) GuidPartitionEntryAttributes_t;
+};
 
-typedef struct _GuidPartitionEntry_t {
+struct __attribute__ ((packed)) _GuidPartitionEntry_t {
 	efi_guid_t PartitionTypeGuid;
 	efi_guid_t UniquePartitionGuid;
 	uint64_t StartingLBA;
 	uint64_t EndingLBA;
 	GuidPartitionEntryAttributes_t Attributes;
 	efi_char16_t PartitionName[72 / sizeof(efi_char16_t)];
-} __attribute__ ((packed)) GuidPartitionEntry_t;
+};
 
 #define GPT_PMBR_LBA 0
 #define GPT_PMBR_SECTORS 1
@@ -181,7 +184,7 @@ typedef struct _GuidPartitionEntry_t {
          sizeof(GuidPartitionEntry_t))
 
 
-typedef struct _PartitionRecord_t {
+struct __attribute__ ((packed)) _PartitionRecord_t {
 	/* Not used by EFI firmware. Set to 0x80 to indicate that this
 	   is the bootable legacy partition. */
 	uint8_t BootIndicator;
@@ -216,24 +219,24 @@ typedef struct _PartitionRecord_t {
 	/* Size of partition in LBA. Used by EFI firmware to determine
 	   the size of the partition. */
 	uint32_t SizeInLBA;
-} __attribute__ ((packed)) PartitionRecord_t;
+};
 
 /* Protected Master Boot Record  & Legacy MBR share same structure */
 /* Needs to be packed because the u16s force misalignment. */
-typedef struct _LegacyMBR_t {
+struct __attribute__ ((packed)) _LegacyMBR_t {
 	uint8_t BootCode[440];
 	uint32_t UniqueMBRSignature;
 	uint16_t Unknown;
 	PartitionRecord_t PartitionRecord[4];
 	uint16_t Signature;
-} __attribute__ ((packed)) LegacyMBR_t;
+};
 
 /* uses libparted's disk_specific field in PedDisk, to store our info */
-typedef struct _GPTDiskData {
+struct __attribute__ ((packed)) _GPTDiskData {
 	PedGeometry	data_area;
 	int		entry_count;
 	efi_guid_t	uuid;
-} GPTDiskData;
+};
 
 /* uses libparted's disk_specific field in PedPartition, to store our info */
 typedef struct _GPTPartitionData {
@@ -360,7 +363,6 @@ pth_get_raw (const PedDevice* dev, const GuidPartitionTableHeader_t* pth)
 static void
 swap_uuid_and_efi_guid(uuid_t uuid)
 {
-	int i;
 	efi_guid_t *guid = (efi_guid_t *)uuid;
 
 	PED_ASSERT(uuid != NULL, return);
@@ -475,7 +477,6 @@ gpt_clobber(PedDevice * dev)
         uint8_t* zeroed_pth_raw = ped_malloc (pth_get_size (dev));
         uint8_t* pth_raw = ped_malloc (pth_get_size (dev));
 	GuidPartitionTableHeader_t* gpt;
-	GuidPartitionEntry_t ptes[GPT_DEFAULT_PARTITION_ENTRIES];
 
 	PED_ASSERT (dev != NULL, return 0);
 
@@ -949,7 +950,7 @@ _write_pmbr (PedDevice * dev)
 }
 
 static void
-_generate_header (PedDisk* disk, int alternate, uint32_t ptes_crc,
+_generate_header (const PedDisk* disk, int alternate, uint32_t ptes_crc,
 		  GuidPartitionTableHeader_t** gpt_p)
 {
 	GPTDiskData* gpt_disk_data = disk->disk_specific;
@@ -1016,7 +1017,7 @@ _partition_generate_part_entry (PedPartition* part, GuidPartitionEntry_t* pte)
 }
 
 static int
-gpt_write(PedDisk * disk)
+gpt_write(const PedDisk * disk)
 {
 	GPTDiskData* gpt_disk_data;
 	GuidPartitionEntry_t* ptes;
@@ -1025,7 +1026,6 @@ gpt_write(PedDisk * disk)
 	GuidPartitionTableHeader_t* gpt;
 	PedPartition* part;
 	int ptes_size;
-	unsigned int i;
 
 	PED_ASSERT (disk != NULL, goto error);
 	PED_ASSERT (disk->dev != NULL, goto error);
@@ -1099,7 +1099,6 @@ add_metadata_part(PedDisk * disk, PedSector start, PedSector length)
 
 error_destroy_constraint:
 	ped_constraint_destroy (constraint_exact);
-error_destroy_part:
 	ped_partition_destroy (part);
 error:
 	return 0;
@@ -1492,15 +1491,14 @@ static PedDiskType gpt_disk_type = {
 void
 ped_disk_gpt_init()
 {
-	PED_ASSERT(sizeof(GuidPartitionEntryAttributes_t) == 8, return);
-	PED_ASSERT(sizeof(GuidPartitionEntry_t) == 128, return);
+	PED_ASSERT (sizeof (GuidPartitionEntryAttributes_t) == 8, return);
+	PED_ASSERT (sizeof (GuidPartitionEntry_t) == 128, return);
 
-	ped_register_disk_type(&gpt_disk_type);
+	ped_disk_type_register (&gpt_disk_type);
 }
 
 void
 ped_disk_gpt_done()
 {
-	ped_unregister_disk_type(&gpt_disk_type);
+	ped_disk_type_unregister (&gpt_disk_type);
 }
-
